==> libgrinvin-core-java_1.0.4.orig.tar.gz: grinvin-core-1.0.4/org/grinvin/gui/icons/GraphIconFactory.java <==
/* GraphIconFactory.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gui.icons;

import org.grinvin.GraphBundleView;

/**
 * An object of this class can return a {@link GraphIcon} for a given graph 
 * at a given size. Graph icon factories are singleton objects which can
 * be referred to by a graph bundle to indicate the preferred way for them
 * to be displayed.<p>
 * To be useful, every implementation of this class must export a class method
 * withthe following signature
 * <pre>
 *     public static GraphIconFactory getInstance ();
 * </pre>
 * which returns the singleton object of its class. The system will call
 * this method using the reflection mechanism.
 */
public interface GraphIconFactory {
    
    //
    public GraphIcon createIcon (GraphBundleView graphBundle, int size);
    
}

==> libgrinvin-core-java_1.2.orig.tar.gz: grinvin-core-1.2/org/grinvin/gui/icons/GraphIconFactory.java <==
/* GraphIconFactory.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gui.icons;

import org.grinvin.graphs.GraphBundleView;

/**
 * An object of this class can return a {@link GraphIcon} for a given graph 
 * at a given size. Graph icon factories are singleton objects which can
 * be referred to by a graph bundle to indicate the preferred way for them
 * to be displayed.<p>
 * To be useful, every implementation of this class must export a class method
 * withthe following signature
 * <pre>
 *     public static GraphIconFactory getInstance ();
 * </pre>
 * which returns the singleton object of its class. The system will call
 * this method using the reflection mechanism.
 */
public interface GraphIconFactory {
    
    //
    public GraphIcon createIcon (GraphBundleView graphBundle, int size);
    
}
